mathtools.yield_all_partitions_of_integer
=========================================

.. autofunction:: abjad.tools.mathtools.yield_all_partitions_of_integer.yield_all_partitions_of_integer
   :noindex:
